# Space separated List of interfaces which needs to be started before
# hostapd
INTERFACES="wlan0"

# Space separated list of configuration files
CONFIGS="/etc/hostapd/hostapd.conf"

# Extra options to pass to hostapd, see hostapd(8)
OPTIONS=""
