#!/bin/sh
# install_openrc_misc.sh

DESTDIR=$1
SYSCONFDIR=${SYSCONFDIR:-etc}

_gentoo_uri="gentoo"

# install
install -Dm755 "${_gentoo_uri}/sys-process/anacron/files/anacron.rc6" "${DESTDIR}/${SYSCONFDIR}/init.d/anacron"
install -Dm755 "${_gentoo_uri}/sys-process/fcron/files/fcron.init.4" "${DESTDIR}/${SYSCONFDIR}/init.d/fcron"
install -Dm644 "${_gentoo_uri}/net-im/bitlbee/files/bitlbee.confd-r2" "${DESTDIR}/${SYSCONFDIR}/conf.d/bitlbee"
install -Dm755 "${_gentoo_uri}/net-im/bitlbee/files/bitlbee.initd-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/bitlbee"
install -Dm644 "${_gentoo_uri}/sys-power/cpupower/files/conf.d-r2" "${DESTDIR}/${SYSCONFDIR}/conf.d/cpupower"
install -Dm755 "${_gentoo_uri}/sys-power/cpupower/files/init.d-r4" "${DESTDIR}/${SYSCONFDIR}/init.d/cpupower"
install -Dm755 "${_gentoo_uri}/net-print/cups/files/cupsd.init.d-r3" "${DESTDIR}/${SYSCONFDIR}/init.d/cupsd"
install -Dm644 "${_gentoo_uri}/net-misc/ntp/files/sntp.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/sntp"
install -Dm755 "${_gentoo_uri}/net-misc/ntp/files/sntp.rc" "${DESTDIR}/${SYSCONFDIR}/init.d/sntp"
install -Dm644 "${_gentoo_uri}/app-admin/rsyslog/files/rsyslog.confd-r1" "${DESTDIR}/${SYSCONFDIR}/conf.d/rsyslog"
install -Dm755 "${_gentoo_uri}/app-admin/rsyslog/files/rsyslog.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/rsyslog"
install -Dm644 "${_gentoo_uri}/media-gfx/sane-backends/files/saned.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/saned"
install -Dm755 "${_gentoo_uri}/media-gfx/sane-backends/files/saned.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/saned"
install -Dm755 "${_gentoo_uri}/sys-fs/fuse-common/files/fuse.init" "${DESTDIR}/${SYSCONFDIR}/init.d/fuse"
install -Dm755 "${_gentoo_uri}/app-admin/mcelog/files/mcelog.init-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/mcelog"
install -Dm644 "${_gentoo_uri}/app-admin/metalog/files/metalog.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/metalog"
install -Dm755 "${_gentoo_uri}/app-admin/metalog/files/metalog.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/metalog"
install -Dm644 "${_gentoo_uri}/app-admin/syslog-ng/files/syslog-ng.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/syslog-ng"
install -Dm755 "${_gentoo_uri}/app-admin/syslog-ng/files/syslog-ng.rc" "${DESTDIR}/${SYSCONFDIR}/init.d/syslog-ng"
install -Dm644 "${_gentoo_uri}/sys-apps/lm-sensors/files/sensord.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/sensord"
install -Dm755 "${_gentoo_uri}/sys-apps/lm-sensors/files/sensord.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/sensord"
install -Dm644 "${_gentoo_uri}/sys-apps/lm-sensors/files/fancontrol.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/fancontrol"
install -Dm755 "${_gentoo_uri}/sys-apps/lm-sensors/files/fancontrol.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/fancontrol"
install -Dm644 "${_gentoo_uri}/sys-apps/lm-sensors/files/lm_sensors.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/lm_sensors"
install -Dm755 "${_gentoo_uri}/sys-apps/lm-sensors/files/lm_sensors.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/lm_sensors"
install -Dm644 "${_gentoo_uri}/app-misc/lirc/files/lircd.conf.4" "${DESTDIR}/${SYSCONFDIR}/conf.d/lircd"
install -Dm755 "${_gentoo_uri}/app-misc/lirc/files/lircd-0.8.6-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/lircd"
install -Dm644 "${_gentoo_uri}/app-misc/lirc/files/irexec-confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/irexec"
install -Dm755 "${_gentoo_uri}/app-misc/lirc/files/irexec-initd-0.9.4a-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/irexec"
install -Dm755 "${_gentoo_uri}/app-misc/lirc/files/lircmd-0.9.4a-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/lircmd"
install -Dm644 "${_gentoo_uri}/sys-apps/haveged/files/haveged-conf.d" "${DESTDIR}/${SYSCONFDIR}/conf.d/haveged"
install -Dm755 "${_gentoo_uri}/sys-apps/haveged/files/haveged-init.d.3" "${DESTDIR}/${SYSCONFDIR}/init.d/haveged"
install -Dm644 "${_gentoo_uri}/app-admin/salt/files/master-confd-1" "${DESTDIR}/${SYSCONFDIR}/conf.d/salt-master"
install -Dm755 "${_gentoo_uri}/app-admin/salt/files/master-initd-5" "${DESTDIR}/${SYSCONFDIR}/init.d/salt-master"
install -Dm644 "${_gentoo_uri}/app-admin/salt/files/minion-confd-1" "${DESTDIR}/${SYSCONFDIR}/conf.d/salt-minion"
install -Dm755 "${_gentoo_uri}/app-admin/salt/files/minion-initd-5" "${DESTDIR}/${SYSCONFDIR}/init.d/salt-minion"
install -Dm644 "${_gentoo_uri}/app-admin/salt/files/syndic-confd-1" "${DESTDIR}/${SYSCONFDIR}/conf.d/salt-syncdic"
install -Dm755 "${_gentoo_uri}/app-admin/salt/files/syndic-initd-5" "${DESTDIR}/${SYSCONFDIR}/init.d/salt-syncdic"
install -Dm755 "${_gentoo_uri}/app-admin/salt/files/api-initd-5" "${DESTDIR}/${SYSCONFDIR}/init.d/salt-api"
install -Dm755 "${_gentoo_uri}/media-sound/mpd/files/mpd-0.21.4.init" "${DESTDIR}/${SYSCONFDIR}/init.d/mpd"
install -Dm644 "${_gentoo_uri}/sys-apps/hdparm/files/hdparm-conf.d.3" "${DESTDIR}/${SYSCONFDIR}/conf.d/hdparm"
install -Dm755 "${_gentoo_uri}/sys-apps/hdparm/files/hdparm-init-8" "${DESTDIR}/${SYSCONFDIR}/init.d/hdparm"
install -Dm755 "${_gentoo_uri}/sys-power/thermald/files/thermald" "${DESTDIR}/${SYSCONFDIR}/init.d/thermald"
install -Dm755 "${_gentoo_uri}/app-emulation/xe-guest-utilities/files/xe-daemon.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/xe-daemon"
install -Dm755 "${_gentoo_uri}/app-emulation/virtualbox-guest-additions/files/virtualbox-guest-additions-8.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/vboxservice"
install -Dm644 "${_gentoo_uri}/sci-misc/boinc/files/boinc.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/boinc"
install -Dm755 "${_gentoo_uri}/sci-misc/boinc/files/boinc.init.in" "${DESTDIR}/${SYSCONFDIR}/init.d/boinc"
install -Dm644 "${_gentoo_uri}/sys-process/at/files/atd.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/atd"
install -Dm755 "${_gentoo_uri}/sys-process/at/files/atd.rc8" "${DESTDIR}/${SYSCONFDIR}/init.d/atd"
install -Dm644 "${_gentoo_uri}/sys-fs/quota/files/quota.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/quota"
install -Dm755 "${_gentoo_uri}/sys-fs/quota/files/quota.rc7" "${DESTDIR}/${SYSCONFDIR}/init.d/quota"
install -Dm755 "${_gentoo_uri}/sys-fs/quota/files/rpc.rquotad.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.rquotad"
install -Dm644 "${_gentoo_uri}/app-emulation/libvirt/files/libvirtd.confd-r5" "${DESTDIR}/${SYSCONFDIR}/conf.d/libvirtd"
install -Dm755 "${_gentoo_uri}/app-emulation/libvirt/files/libvirtd.init-r19" "${DESTDIR}/${SYSCONFDIR}/init.d/libvirtd"
install -Dm755 "${_gentoo_uri}/app-emulation/libvirt/files/virtlockd.init-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/virtlockd"
install -Dm755 "${_gentoo_uri}/app-emulation/libvirt/files/virtlogd.init-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/virtlogd"
install -Dm644 "${_gentoo_uri}/sys-process/dcron/files/dcron.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/dcron"
install -Dm755 "${_gentoo_uri}/sys-process/dcron/files/dcron.init" "${DESTDIR}/${SYSCONFDIR}/init.d/dcron"
install -Dm644 "${_gentoo_uri}/app-admin/sysklogd/files/sysklogd.confd3" "${DESTDIR}/${SYSCONFDIR}/conf.d/sysklogd"
install -Dm755 "${_gentoo_uri}/app-admin/sysklogd/files/sysklogd.rc10" "${DESTDIR}/${SYSCONFDIR}/init.d/sysklogd"
install -Dm644 "misc/conf.d/sendmail.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/sendmail"
install -Dm755 "${_gentoo_uri}/mail-mta/sendmail/files/sendmail" "${DESTDIR}/${SYSCONFDIR}/init.d/sendmail"
install -Dm755 "${_gentoo_uri}/app-admin/ulogd/files/ulogd.init" "${DESTDIR}/${SYSCONFDIR}/init.d/ulogd"
install -Dm755 "${_gentoo_uri}/app-admin/monit/files/monit.initd-5.0-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/monit"
install -Dm755 "${_gentoo_uri}/sys-power/thermald/files/thermald" "${DESTDIR}/${SYSCONFDIR}/init.d/thermald"
install -Dm755 "misc/init.d/zfs.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/zfs"
install -Dm755 "misc/init.d/netdata-openrc.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/netdata"
install -Dm644 "misc/conf.d/docker.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/docker"
install -Dm755 "misc/init.d/docker.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/docker"
install -Dm755 "misc/init.d/cgmanager.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/cgmanager"
install -Dm755 "misc/init.d/cgproxy.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/cgproxy"
install -Dm644 "misc/conf.d/clamd.conf-r1" "${DESTDIR}/${SYSCONFDIR}/conf.d/clamd"
install -Dm755 "misc/init.d/clamd.initd-r6" "${DESTDIR}/${SYSCONFDIR}/init.d/clamd"
#install -Dm755 "${_gentoo_uri}/app-crypt/mit-krb5/files/mit-krb5kadmind.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/krb5kadmind"
#install -Dm755 "${_gentoo_uri}/app-crypt/mit-krb5/files/mit-krb5kdc.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/krb5kdc"
#install -Dm755 "${_gentoo_uri}/app-crypt/mit-krb5/files/mit-krb5kpropd.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/krb5kpropd"

