#!/sbin/openrc-run
# Copyright 1999-2006 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

depend() {
	use logger dns net
}

start() {
	ebegin "Starting mdadm monitor"
	mdadm --monitor --scan \
		--daemonise \
		--pid-file /var/run/mdadm.pid \
		${MDADM_OPTS}
	eend $?
}

stop() {
	local ret
	ebegin "Stopping mdadm monitor"
	start-stop-daemon --stop --pidfile /var/run/mdadm.pid
	ret=$?
	rm -f /var/run/mdadm.pid
	eend ${ret}
}
