# conf.d file for wpa_supplicant

# uncomment this if wpa_supplicant starts up before your network interface
# is ready and it causes issues
# rc_want="dev-settle"

# Please check man 8 wpa_supplicant for more information about the options
# wpa_supplicant accepts.
#
wpa_supplicant_args=""
