# Copyright 1999-2011 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

WATERMARK=1024

# -r0 is added always
HAVEGED_OPTS="-w ${WATERMARK} -v 1"

# vim:ft=gentoo-conf-d:
