#!/sbin/openrc-run
# Copyright 1999-2009 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

command=/usr/bin/espeakup
command_args="${espeakup_opts:-${ESPEAKUP_OPTS}}"
pidfile=/run/espeakup.pid

depend() {
	after modules
	use alsasound pulseaudio
}
