#!/sbin/openrc-run

config=/etc/influxdb/influxd.conf
pidfile=/var/run/influxd.pid
command=/usr/bin/influxd
command_args="-config ${config}  -pidfile ${pidfile} ${influxd_opts}"
command_args="-config ${config}  ${influxd_opts}"
command_background=yes
make_pidfile=yes
command_user="influxdb:influxdb"
retry=SIGTERM/30/SIGKILL/10
wait=1000

# Logging
error_log="${error_log:-/var/log/influxdb/influxd.log}"
output_log="${output_log:-/dev/null}"

# Max open files
rc_ulimit="-n 65536"

start_pre() {
	# Check if config file exist
	if [ ! -r ${config} ]; then
		eerror "config file ${config} doesn't exist"
	    return 1
	fi
	if [ ! -f "$error_log" ]; then
		mkdir -p "$(dirname $error_log)"
	fi
	if [ ! -f "$output_log" ]; then
		mkdir -p "$(dirname $output_log)"
	fi
	return 0
}
