#!/bin/sh
# install_openrc_net.sh

DESTDIR=$1
SYSCONFDIR=${SYSCONFDIR:-etc}

_gentoo_uri="gentoo"

# install
install -Dm755 "${_gentoo_uri}/net-fs/autofs/files/autofs5.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/autofs"
install -Dm644 "${_gentoo_uri}/net-misc/connman/files/connman.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/connman"
install -Dm755 "${_gentoo_uri}/net-misc/connman/files/connman.initd2" "${DESTDIR}/${SYSCONFDIR}/init.d/connman"
install -Dm644 "${_gentoo_uri}/net-dns/bind/files/named.confd-r7" "${DESTDIR}/${SYSCONFDIR}/conf.d/named"
install -Dm755 "${_gentoo_uri}/net-dns/bind/files/named.init-r14" "${DESTDIR}/${SYSCONFDIR}/init.d/named"
install -Dm644 "${_gentoo_uri}/dev-libs/cyrus-sasl/files/saslauthd-2.1.26.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/saslauthd"
install -Dm755 "${_gentoo_uri}/dev-libs/cyrus-sasl/files/saslauthd2.rc7" "${DESTDIR}/${SYSCONFDIR}/init.d/saslauthd"
install -Dm644 "${_gentoo_uri}/net-misc/dhcp/files/dhcpd.conf2" "${DESTDIR}/${SYSCONFDIR}/conf.d/dhcpd"
install -Dm755 "${_gentoo_uri}/net-misc/dhcp/files/dhcpd.init5" "${DESTDIR}/${SYSCONFDIR}/init.d/dhcpd"
install -Dm644 "${_gentoo_uri}/net-misc/dhcp/files/dhcrelay.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/dhcrelay"
install -Dm755 "${_gentoo_uri}/net-misc/dhcp/files/dhcrelay.init3" "${DESTDIR}/${SYSCONFDIR}/init.d/dhcrelay"
install -Dm644 "${_gentoo_uri}/net-misc/dhcp/files/dhcrelay6.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/dhcrelay6"
install -Dm755 "${_gentoo_uri}/net-misc/dhcp/files/dhcrelay.init3" "${DESTDIR}/${SYSCONFDIR}/init.d/dhcrelay6"
install -Dm644 "${_gentoo_uri}/net-firewall/iptables/files/iptables-r1.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/iptables"
install -Dm755 "${_gentoo_uri}/net-firewall/iptables/files/iptables-r2.init" "${DESTDIR}/${SYSCONFDIR}/init.d/iptables"
install -Dm644 "${_gentoo_uri}/net-firewall/iptables/files/ip6tables-r1.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/ip6tables"
install -Dm755 "${_gentoo_uri}/net-firewall/iptables/files/iptables-r2.init" "${DESTDIR}/${SYSCONFDIR}/init.d/ip6tables"
install -Dm644 "${_gentoo_uri}/net-nds/rpcbind/files/rpcbind.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/rpcbind"
install -Dm755 "${_gentoo_uri}/net-nds/rpcbind/files/rpcbind.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpcbind"
install -Dm644 "${_gentoo_uri}/net-fs/nfs-utils/files/nfs.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/nfs"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/nfs.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/nfs"
install -Dm644 "${_gentoo_uri}/net-fs/nfs-utils/files/nfsclient.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/nfsclient"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/nfsclient.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/nfsclient"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/rpc.gssd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.gssd"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/rpc.idmapd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.idmapd"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/rpc.pipefs.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.pipefs"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/rpc.statd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.statd"
install -Dm755 "${_gentoo_uri}/net-fs/nfs-utils/files/rpc.svcgssd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/rpc.svcgssd"
install -Dm644 "${_gentoo_uri}/net-misc/ntp/files/ntpd.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/ntpd"
install -Dm755 "${_gentoo_uri}/net-misc/ntp/files/ntpd.rc-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/ntpd"
install -Dm644 "${_gentoo_uri}/net-misc/ntp/files/ntp-client.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/ntp-client"
install -Dm755 "${_gentoo_uri}/net-misc/ntp/files/ntp-client.rc" "${DESTDIR}/${SYSCONFDIR}/init.d/ntp-client"
install -Dm644 "${_gentoo_uri}/net-misc/openntpd/files/openntpd.conf.d-20080406-r6" "${DESTDIR}/${SYSCONFDIR}/conf.d/openntpd"
install -Dm755 "${_gentoo_uri}/net-misc/openntpd/files/openntpd.init.d-20080406-r6" "${DESTDIR}/${SYSCONFDIR}/init.d/openntpd"
install -Dm644 "${_gentoo_uri}/net-misc/chrony/files/chronyd.conf-r3" "${DESTDIR}/${SYSCONFDIR}/conf.d/chronyd"
install -Dm755 "${_gentoo_uri}/net-misc/chrony/files/chronyd.init-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/chronyd"
install -Dm644 "${_gentoo_uri}/net-nds/openldap/files/slapd-confd-2.4.28-r1" "${DESTDIR}/${SYSCONFDIR}/conf.d/slapd"
install -Dm755 "${_gentoo_uri}/net-nds/openldap/files/slapd-initd-2.4.40-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/slapd"
install -Dm644 "${_gentoo_uri}/net-misc/openssh/files/sshd-r1.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/sshd"
install -Dm755 "${_gentoo_uri}/net-misc/openssh/files/sshd-r2.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/sshd"
install -Dm644 "${_gentoo_uri}/net-vpn/openvpn/files/openvpn-2.1.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/openvpn"
install -Dm755 "${_gentoo_uri}/net-vpn/openvpn/files/openvpn-2.1.init" "${DESTDIR}/${SYSCONFDIR}/init.d/openvpn"
install -Dm755 "${_gentoo_uri}/mail-mta/postfix/files/postfix.rc6.2.7" "${DESTDIR}/${SYSCONFDIR}/init.d/postfix"
install -Dm755 "${_gentoo_uri}/net-proxy/privoxy/files/privoxy.initd-3" "${DESTDIR}/${SYSCONFDIR}/init.d/privoxy"
install -Dm644 "${_gentoo_uri}/net-misc/rsync/files/rsyncd.conf.d" "${DESTDIR}/${SYSCONFDIR}/conf.d/rsyncd"
install -Dm755 "${_gentoo_uri}/net-misc/rsync/files/rsyncd.init.d-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/rsyncd"
install -Dm644 "${_gentoo_uri}/net-fs/samba/files/4.4/samba4.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/samba"
install -Dm755 "${_gentoo_uri}/net-fs/samba/files/4.4/samba4.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/samba"
install -Dm644 "${_gentoo_uri}/net-proxy/squid/files/squid.confd-r2" "${DESTDIR}/${SYSCONFDIR}/conf.d/squid"
install -Dm755 "${_gentoo_uri}/net-proxy/squid/files/squid.initd-r5" "${DESTDIR}/${SYSCONFDIR}/init.d/squid"
install -Dm644 "${_gentoo_uri}/net-p2p/transmission/files/transmission-daemon.confd.4" "${DESTDIR}/${SYSCONFDIR}/conf.d/transmission-daemon"
install -Dm755 "${_gentoo_uri}/net-p2p/transmission/files/transmission-daemon.initd.10" "${DESTDIR}/${SYSCONFDIR}/init.d/transmission-daemon"
install -Dm644 "${_gentoo_uri}/net-firewall/ufw/files/ufw.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/ufw"
install -Dm755 "${_gentoo_uri}/net-firewall/ufw/files/ufw-2.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/ufw"
install -Dm755 "${_gentoo_uri}/net-ftp/vsftpd/files/vsftpd.init-3.0.5" "${DESTDIR}/${SYSCONFDIR}/init.d/vsftpd"
install -Dm755 "${_gentoo_uri}/net-ftp/proftpd/files/proftpd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/proftpd"
install -Dm644 "${_gentoo_uri}/net-analyzer/vnstat/files/vnstatd.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/vnstatd"
install -Dm755 "${_gentoo_uri}/net-analyzer/vnstat/files/vnstatd.initd-r1" "${DESTDIR}/${SYSCONFDIR}/init.d/vnstatd"
install -Dm644 "${_gentoo_uri}/sys-apps/xinetd/files/xinetd.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/xinetd"
install -Dm755 "${_gentoo_uri}/sys-apps/xinetd/files/xinetd.rc6" "${DESTDIR}/${SYSCONFDIR}/init.d/xinetd"
install -Dm644 "${_gentoo_uri}/net-vpn/tor/files/tor.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/tor"
install -Dm755 "${_gentoo_uri}/net-vpn/tor/files/tor.initd-r9" "${DESTDIR}/${SYSCONFDIR}/init.d/tor"
install -Dm644 "${_gentoo_uri}/www-servers/nginx/files/nginx.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/nginx"
install -Dm755 "${_gentoo_uri}/www-servers/nginx/files/nginx.initd-r4" "${DESTDIR}/${SYSCONFDIR}/init.d/nginx"
install -Dm644 "${_gentoo_uri}/net-dns/dnsmasq/files/dnsmasq.confd-r1" "${DESTDIR}/${SYSCONFDIR}/conf.d/dnsmasq"
install -Dm755 "${_gentoo_uri}/net-dns/dnsmasq/files/dnsmasq-init-r4" "${DESTDIR}/${SYSCONFDIR}/init.d/dnsmasq"
install -Dm644 "${_gentoo_uri}/net-p2p/syncthing/files/syncthing.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/syncthing"
install -Dm755 "${_gentoo_uri}/net-p2p/syncthing/files/syncthing.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/syncthing"
install -Dm755 "${_gentoo_uri}/net-misc/teamviewer/files/teamviewerd15.init" "${DESTDIR}/${SYSCONFDIR}/init.d/teamviewerd"
install -Dm644 "${_gentoo_uri}/net-ftp/tftp-hpa/files/in.tftpd.confd-0.44" "${DESTDIR}/${SYSCONFDIR}/conf.d/tftpd-hpa"
install -Dm755 "${_gentoo_uri}/net-ftp/tftp-hpa/files/in.tftpd.rc6" "${DESTDIR}/${SYSCONFDIR}/init.d/tftpd-hpa"
install -Dm644 "${_gentoo_uri}/net-analyzer/net-snmp/files/snmpd.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/snmpd"
install -Dm755 "${_gentoo_uri}/net-analyzer/net-snmp/files/snmpd.init.2" "${DESTDIR}/${SYSCONFDIR}/init.d/snmpd"
install -Dm644 "${_gentoo_uri}/net-analyzer/net-snmp/files/snmptrapd.conf" "${DESTDIR}/${SYSCONFDIR}/conf.d/snmptrapd"
install -Dm755 "${_gentoo_uri}/net-analyzer/net-snmp/files/snmptrapd.init.2" "${DESTDIR}/${SYSCONFDIR}/init.d/snmptrapd"
install -Dm644 "${_gentoo_uri}/net-wireless/wpa_supplicant/files/wpa_supplicant-conf.d" "${DESTDIR}/${SYSCONFDIR}/conf.d/wpa_supplicant"
install -Dm755 "${_gentoo_uri}/net-wireless/wpa_supplicant/files/wpa_supplicant-init.d" "${DESTDIR}/${SYSCONFDIR}/init.d/wpa_supplicant"
install -Dm755 "${_gentoo_uri}/net-wireless/wpa_supplicant/files/wpa_cli.sh" "${DESTDIR}/etc/wpa_supplicant/wpa_cli.sh"
install -Dm644 "${_gentoo_uri}/net-misc/networkmanager/files/conf.d.NetworkManager" "${DESTDIR}/${SYSCONFDIR}/conf.d/NetworkManager"
install -Dm755 "${_gentoo_uri}/net-misc/networkmanager/files/init.d.NetworkManager-r2" "${DESTDIR}/${SYSCONFDIR}/init.d/NetworkManager"
install -Dm755 "${_gentoo_uri}/net-misc/networkmanager/files/10-openrc-status-r4" "${DESTDIR}/etc/NetworkManager/dispatcher.d/10-openrc-status"
install -Dm644 "${_gentoo_uri}/net-dns/dnscrypt-proxy/files/dnscrypt-proxy.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/dnscrypt-proxy"
install -Dm755 "${_gentoo_uri}/net-dns/dnscrypt-proxy/files/dnscrypt-proxy.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/dnscrypt-proxy"
install -Dm644 "${_gentoo_uri}/net-dns/unbound/files/unbound-r1.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/unbound"
install -Dm755 "${_gentoo_uri}/net-dns/unbound/files/unbound-r1.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/unbound"
install -Dm755 "misc/init.d/wicd.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/wicd"
install -Dm644 "misc/conf.d/fail2ban.confd" "${DESTDIR}/${SYSCONFDIR}/conf.d/fail2ban"
install -Dm755 "misc/init.d/fail2ban.initd" "${DESTDIR}/${SYSCONFDIR}/init.d/fail2ban"
install -Dm644 "misc/net-wireless_hostapd_2.7-r2_extras/hostapd-conf.d" "${DESTDIR}/${SYSCONFDIR}/conf.d/hostapd"
install -Dm755 "misc/net-wireless_hostapd_2.7-r2_extras/hostapd-init.d" "${DESTDIR}/${SYSCONFDIR}/init.d/hostapd"
install -Dm755 "misc/init.d/polipo.initd-5" "${DESTDIR}/${SYSCONFDIR}/init.d/polipo"
#install -Dm755 "${_gentoo_uri}/net-nds/openldap/files/slpd-init" "${DESTDIR}/${SYSCONFDIR}/init.d/slpd"

