#!/sbin/openrc-run
# Copyright 1999-2013 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

command=/bin/brltty
pidfile=/var/run/brltty.pid
command_args="-P $pidfile -q"

depend() {
	before *
	after clock
}
